@@ -138,11 +138,11 @@ type Nums = [usize; NUMS_LEN];
 /// # Examples
 ///
 /// ```
-/// use hash_arr_map::HashArrMap;
+/// use hash_arr_map::Ham;
 ///
 /// // Type inference lets us omit an explicit type signature (which
-/// // would be `HashArrMap<i32, i32>` in this example).
-/// let mut squares = HashArrMap::new();
+/// // would be `Ham<i32, i32>` in this example).
+/// let mut squares = Ham::new();
 ///
 /// // Square some numbers.
 /// squares.insert(1, 1);
@@ -167,18 +167,18 @@ type Nums = [usize; NUMS_LEN];
 /// }
 /// ```
 ///
-/// `HashArrMap` also implements an [`Entry API`](#method.entry), which allows
+/// `Ham` also implements an [`Entry API`](#method.entry), which allows
 /// for more complex methods of getting, setting, updating and removing keys and
 /// their values:
 ///
 /// ```rust
-/// use hash_arr_map::HashArrMap;
+/// use hash_arr_map::Ham;
 ///
 /// let text = "Rust's strings are utf-8 \u{2764}";
 ///
 /// // Type inference lets us not say what type of map this is.
-/// // (`HashArrMap<char, usize>` in this example)
-/// let mut map = HashArrMap::new();
+/// // (`Ham<char, usize>` in this example)
+/// let mut map = Ham::new();
 ///
 /// for c in text.chars() {
 ///     map.entry(c).and_modify(|c| *c += 1).or_insert(1_usize);
@@ -189,7 +189,7 @@ type Nums = [usize; NUMS_LEN];
 /// assert_eq!(map[&'❤'], 1);
 /// ```
 ///
-/// The easiest way to use `HashArrMap` with a custom key type is to derive [`Eq`] and [`Hash`],
+/// The easiest way to use `Ham` with a custom key type is to derive [`Eq`] and [`Hash`],
 /// then implement [`IntoIndex`] and [`FromIndex`] for it.
 /// We must also derive [`PartialEq`].
 ///
@@ -201,7 +201,7 @@ type Nums = [usize; NUMS_LEN];
 /// ```
 /// use core::num::NonZeroUsize;
 ///
-/// use hash_arr_map::{FromIndex, HashArrMap, IntoIndex};
+/// use hash_arr_map::{FromIndex, Ham, IntoIndex};
 ///
 /// #[derive(Hash, Eq, PartialEq, Debug)]
 /// struct Item {
@@ -232,7 +232,7 @@ type Nums = [usize; NUMS_LEN];
 /// }
 ///
 /// // Use a HashMap to store the item's quantity.
-/// let mut items = HashArrMap::new();
+/// let mut items = Ham::new();
 ///
 /// items.insert(Item::new(10, 0), 25);
 /// items.insert(Item::new(5, 50), 24);
@@ -259,44 +259,60 @@ type Nums = [usize; NUMS_LEN];
 /// ```
 /// use std::borrow::Cow;
 ///
-/// use hash_arr_map::HashArrMap;
+/// use hash_arr_map::Ham;
 ///
-/// let timber_resources: HashArrMap<Cow<str>, i32> =
-///     [("Norway", 100), ("Denmark", 50), ("Iceland", 10)]
-///         .iter()
-///         .copied()
-///         .map(|(k, v)| (Cow::Borrowed(k), v))
-///         .collect();
+/// let timber_resources: Ham<Cow<str>, u32> = [("Norway", 100), ("Denmark", 50), ("Iceland", 10)]
+///     .iter()
+///     .copied()
+///     .map(|(k, v)| (Cow::Borrowed(k), v))
+///     .collect();
 /// // use the values stored in map
 /// ```
+///
+/// References cannot be used as keys, as they cannot be easily converted to
+/// indexes and back:
+///
+/// ```rust,compile_fail
+/// use hash_arr_map::Ham;
+///
+/// // This is inferred as `Ham<&str, i32>`.
+/// let mut h = Ham::new();
+///
+/// h.insert("test", 101);
+/// ```
 #[cfg_attr(feature = "gc", derive(gc::Trace))]
 #[derive(Clone)]
-pub struct HashArrMap<K, V> {
+pub struct Ham<K, V> {
     array: Vec<Option<V>>,
     hash: Vec<Node<K, V>>,
 
-    len: usize,       // The amount of `Some`s in the array
-    last_free: usize, // The last free node in the hash part.
+    // How many values are currently stored
+    len: usize,
+
+    // The last free node in the hash part.
+    last_free: usize,
+
+    // To build the hasher that is used to hash keys.
     #[cfg_attr(feature = "gc", unsafe_ignore_trace)]
     hash_builder: LuaBuildHasher,
 }
 
-impl<K: FromIndex + fmt::Debug, V: fmt::Debug> fmt::Debug for HashArrMap<K, V> {
+impl<K: FromIndex + fmt::Debug, V: fmt::Debug> fmt::Debug for Ham<K, V> {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         f.debug_map().entries(self.iter()).finish()
     }
 }
 
 #[cfg(feature = "std")]
-impl<K, V> Default for HashArrMap<K, V> {
+impl<K, V> Default for Ham<K, V> {
     fn default() -> Self {
         Self::new()
     }
 }
 
 #[cfg(feature = "std")]
-impl<K, V> HashArrMap<K, V> {
-    /// Creates a new `HashArrMap`.
+impl<K, V> Ham<K, V> {
+    /// Creates a new `Ham`.
     #[must_use]
     pub fn new() -> Self {
         Self {
@@ -308,7 +324,7 @@ impl<K, V> HashArrMap<K, V> {
         }
     }
 
-    /// Creates a new `HashArrMap` with a specific capacity.
+    /// Creates a new `Ham` with a specific capacity.
     #[must_use]
     pub fn with_capacity(array_part: usize, hash_part: usize) -> Self {
         let mut array = Vec::with_capacity(array_part);
@@ -331,8 +347,8 @@ impl<K, V> HashArrMap<K, V> {
     }
 }
 
-impl<K, V> HashArrMap<K, V> {
-    /// Creates a new `HashArrMap` with a specific seed.
+impl<K, V> Ham<K, V> {
+    /// Creates a new `Ham` with a specific seed.
     #[must_use]
     pub const fn with_seed(seed: u64) -> Self {
         Self {
@@ -344,7 +360,7 @@ impl<K, V> HashArrMap<K, V> {
         }
     }
 
-    /// Creates a new `HashArrMap` with a specific capacity and a specific seed.
+    /// Creates a new `Ham` with a specific capacity and a specific seed.
     #[must_use]
     pub fn with_capacity_and_seed(array_part: usize, hash_part: usize, seed: u64) -> Self {
         let mut array = Vec::with_capacity(array_part);
@@ -364,6 +380,7 @@ impl<K, V> HashArrMap<K, V> {
         }
     }
 
+    /// How many elements the `Ham` has eaten.
     #[must_use]
     pub const fn len(&self) -> usize {
         self.len
@@ -374,11 +391,14 @@ impl<K, V> HashArrMap<K, V> {
         self.len == 0
     }
 
+    /// Returns the number of elements in both sections the `Ham` can eat
+    /// without having to allocate.
     #[must_use]
     pub fn capacity(&self) -> (usize, usize) {
         (self.array.len(), self.hash.len())
     }
 
+    /// Empties the `Ham`.
     pub fn clear(&mut self) {
         self.len = 0;
 
@@ -475,7 +495,7 @@ impl<K, V> HashArrMap<K, V> {
     }
 }
 
-impl<K: FromIndex, V> HashArrMap<K, V> {
+impl<K: FromIndex, V> Ham<K, V> {
     pub fn iter(&self) -> Iter<'_, K, V> {
         Iter {
             array: self.array.iter().enumerate(),
@@ -513,7 +533,7 @@ impl<K: FromIndex, V> HashArrMap<K, V> {
     }
 }
 
-impl<K: FromIndex + Hash + Eq, V> HashArrMap<K, V> {
+impl<K: FromIndex + Hash + Eq, V> Ham<K, V> {
     /// This function finds a boundary in the `table`, such that `table.get(n)`
     /// is `Some(_)`, and `table.get(n + 1)` is `None`.
     pub fn get_n(&self) -> Option<usize> {
@@ -595,9 +615,9 @@ impl<K: FromIndex + Hash + Eq, V> HashArrMap<K, V> {
     /// # Examples
     ///
     /// ```rust
-    /// use hash_arr_map::HashArrMap;
+    /// use hash_arr_map::Ham;
     ///
-    /// let mut map = HashArrMap::new();
+    /// let mut map = Ham::new();
     /// map.insert(1, "a");
     /// assert_eq!(map.remove_entry(&1), Some((1, "a")));
     /// assert_eq!(map.remove(&1), None);
@@ -622,15 +642,15 @@ impl<K: FromIndex + Hash + Eq, V> HashArrMap<K, V> {
     }
 }
 
-impl<K: IntoIndex + FromIndex + Hash + Eq, V> HashArrMap<K, V> {
+impl<K: IntoIndex + FromIndex + Hash + Eq, V> Ham<K, V> {
     /// Gets the given key’s corresponding entry in the map for in-place manipulation.
     ///
     /// # Examples
     ///
     /// ```rust
-    /// use hash_arr_map::HashArrMap;
+    /// use hash_arr_map::Ham;
     ///
-    /// let mut letters = HashArrMap::new();
+    /// let mut letters = Ham::new();
     ///
     /// for ch in "a short treatise on fungi".chars() {
     ///     let counter = letters.entry(ch).or_insert(0);
@@ -647,7 +667,7 @@ impl<K: IntoIndex + FromIndex + Hash + Eq, V> HashArrMap<K, V> {
         Entry::make_new(self, k) // Private helper
     }
 
-    /// Inserts a key-value pair into the map.
+    /// Feed the `Ham` with a key-value pair.
     ///
     /// If the map did not have this key present, [`None`] is returned.
     ///
@@ -657,9 +677,9 @@ impl<K: IntoIndex + FromIndex + Hash + Eq, V> HashArrMap<K, V> {
     /// # Examples
     ///
     /// ```
-    /// use hash_arr_map::HashArrMap;
+    /// use hash_arr_map::Ham;
     ///
-    /// let mut map = HashArrMap::new();
+    /// let mut map = Ham::new();
     /// assert_eq!(map.insert(37, "a"), None);
     /// assert_eq!(map.is_empty(), false);
     ///
@@ -708,7 +728,7 @@ impl<K: IntoIndex + FromIndex + Hash + Eq, V> HashArrMap<K, V> {
     }
 }
 
-impl<K: IntoIndex + FromIndex + Hash + Eq, V> HashArrMap<K, V> {
+impl<K: IntoIndex + FromIndex + Hash + Eq, V> Ham<K, V> {
     fn insert_and_get_mut(&mut self, key: K, value: V) -> &mut V {
         if let Some(idx) = self.get_array_idx_only(&key) {
             // To get it past the borrow checker...
@@ -1052,7 +1072,7 @@ impl<K: IntoIndex + FromIndex + Hash + Eq, V> HashArrMap<K, V> {
     }
 }
 
-impl<K, V> HashArrMap<K, V> {
+impl<K, V> Ham<K, V> {
     // @@@@@@  @@@@@@  @@@@@@  @@@@@@  @@@@@@  @@@@    @@@@@@
     // @@      @@        @@      @@    @@      @@  @@  @@
     // @@ @@@  @@@@      @@      @@    @@@@    @@@@    @@@@@@
@@ -1298,7 +1318,7 @@ impl<K, V> HashArrMap<K, V> {
     }
 }
 
-impl<K, Q: ?Sized, V> Index<&Q> for HashArrMap<K, V>
+impl<K, Q: ?Sized, V> Index<&Q> for Ham<K, V>
 where
     K: Hash + Eq + Borrow<Q>,
     Q: IntoIndex + Hash + Eq,
@@ -1310,7 +1330,7 @@ where
     }
 }
 
-impl<K, Q: ?Sized, V> IndexMut<&Q> for HashArrMap<K, V>
+impl<K, Q: ?Sized, V> IndexMut<&Q> for Ham<K, V>
 where
     K: Hash + Eq + Borrow<Q>,
     Q: IntoIndex + Hash + Eq,
@@ -1321,7 +1341,7 @@ where
 }
 
 #[cfg(feature = "std")]
-impl<K, V> FromIterator<(K, V)> for HashArrMap<K, V>
+impl<K, V> FromIterator<(K, V)> for Ham<K, V>
 where
     K: IntoIndex + FromIndex + Hash + Eq,
 {
@@ -1329,13 +1349,13 @@ where
     where
         I: IntoIterator<Item = (K, V)>,
     {
-        let mut map = HashArrMap::new();
+        let mut map = Ham::new();
         map.extend(iter);
         map
     }
 }
 
-impl<K, V> Extend<(K, V)> for HashArrMap<K, V>
+impl<K, V> Extend<(K, V)> for Ham<K, V>
 where
     K: IntoIndex + FromIndex + Hash + Eq,
 {
@@ -1357,7 +1377,7 @@ mod tests {
 
     #[test]
     fn test_insert() {
-        let mut hash_map = HashArrMap::with_seed(0);
+        let mut hash_map = Ham::with_seed(0);
 
         for i in 0..SIZE {
             hash_map.insert(i, i);
@@ -1366,7 +1386,7 @@ mod tests {
 
     #[test]
     fn test_insert_remove() {
-        let mut hash_map = HashArrMap::with_seed(0);
+        let mut hash_map = Ham::with_seed(0);
 
         for i in 0..SIZE {
             hash_map.insert(i, i);
@@ -1381,7 +1401,7 @@ mod tests {
 
     #[test]
     fn test_insert_remove_2() {
-        let mut hash_map = HashArrMap::with_seed(0);
+        let mut hash_map = Ham::with_seed(0);
 
         for i in 0..100 {
             hash_map.insert(i, i);
